using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Threading;

namespace DeleteLogs
{
    public partial class FormMain : Form
    {
        public FormMain()
        {
            InitializeComponent();
        }



        private void buttonBroswer_Click(object sender, EventArgs e)
        {
            DialogResult dr = folderBrowserDialog.ShowDialog();
            if (dr == DialogResult.OK)
            {
                textBoxRootDir.Text = folderBrowserDialog.SelectedPath;
            }
        }

        public void SetParameters(string dir, int days, string logType,bool autoStart)
        {
            textBoxRootDir.Text = dir;
            textBoxDays.Text = days.ToString();
            textBoxFileTypes.Text = logType;
            _autoStart = autoStart;
        }

        private Thread _deleteThread;
        private string _rootDir;
        private bool _stop = true;
        private const int SLEEP_TIME = 15;
        private int _days = 14;
        private DateTime _deleteLimitTime;
        private string _logFileType;
        private bool _autoStart;

        private void buttonStart_Click(object sender, EventArgs e)
        {
            _rootDir = textBoxRootDir.Text;
            if (string.IsNullOrEmpty(_rootDir))
            {
                MessageBox.Show("ѡ־Ŀ¼");
                return;
            }
            bool isExists = Directory.Exists(_rootDir);
            if (!isExists)
            {
                MessageBox.Show("ѡĿ¼ڣѡĿ¼");
                return;
            }

            string strDays = textBoxDays.Text;
            if (!string.IsNullOrEmpty(strDays))
            {
                if (!int.TryParse(strDays, out _days)) _days = 14;
            }
            _deleteLimitTime = DateTime.Now.AddDays(0 - _days);

            _logFileType = (string.IsNullOrEmpty(textBoxFileTypes.Text) ? "*.log" : textBoxFileTypes.Text);

            _stop = false;

            _deleteThread = new Thread(new ThreadStart(DoDelete));
            _deleteThread.Priority = ThreadPriority.Lowest;
            _deleteThread.Start();
        }

        private void DoDelete()
        {
            DirectoryInfo dir = new DirectoryInfo(_rootDir);

            ProcessDir(dir);
        }

        private void ProcessDir(DirectoryInfo dir)
        {
            textBoxLogs.Invoke(new Do(SetTxt),":" + dir.FullName);
            if (_stop)
            {
                return;
            }
            FileInfo[] files = dir.GetFiles(_logFileType);
            if (files != null)
            {
                for (int i = 0; i < files.Length; i++)
                {
                    if (_stop)
                    {
                        break;
                    }
                    FileInfo file = files[i];
                    bool shouldDelete = file.LastWriteTime < _deleteLimitTime;
                    if (shouldDelete)
                    {
                        textBoxLogs.Invoke(new Do(SetTxt),"ɾ:" + file.FullName);
                        file.Delete();

                        Thread.Sleep(SLEEP_TIME);
                    }
                }
            }
            DirectoryInfo[] subDirs = dir.GetDirectories();
            foreach (DirectoryInfo subDir in subDirs)
            {
                if (_stop)
                {
                    break;
                }
                ProcessDir(subDir);
                Thread.Sleep(SLEEP_TIME * 4);
            }
            textBoxLogs.Invoke(new Do(SetTxt),"ɴ:" + dir.FullName);
        }

        private void buttonStop_Click(object sender, EventArgs e)
        {
            _stop = true;
            Thread.Sleep(100);
            if (_deleteThread != null && _deleteThread.ThreadState != ThreadState.Stopped)
            {
                _deleteThread.Abort();
            }
            textBoxLogs.Invoke(new Do(SetTxt),"ֹͣ");
        }

        delegate void Do(string txt);
        private void SetTxt(string txt)
        {
            textBoxLogs.AppendText(txt + Environment.NewLine);
        }

        private void FormMain_Load(object sender, EventArgs e)
        {
            if (_autoStart)
            {
                buttonStart_Click(null, EventArgs.Empty);
            }
        }
    }
}